@@ -20,7 +20,6 @@ var SHADOW_COLOR = "#77000000";
 var SHADOW_OFFSET = 3;
 
 var DEFAULT_BACKGROUND_COLOR = UBUNTU_ORANGE_COLOR;
-//var DEFAULT_BACKGROUND_COLOR = LIGHT_AUBERGINE_COLOR;
 
 var DEFAULT_FOREGROUND_COLOR = "white";
 
@@ -37,8 +36,9 @@ var DEFAULT_TEXT_COLOR = DEFAULT_FOREGROUND_COLOR;
 
 var DEFAULT_FOLDER = "file:///home/user/MyDocs";
 
-var SYSTEM_BAR_HEIGHT = 60;
-var TEXT_MARGIN = 30;
+var SYSTEM_BAR_HEIGHT = 70;
+var TOP_BAR_HEIGHT = 10;
+var TEXT_MARGIN = 25;
 
 // images
 
